@@ -41,7 +41,7 @@ from __future__ import annotations
 import re
 from contextlib import suppress
 from textwrap import dedent
-from typing import TYPE_CHECKING, Any, Pattern
+from typing import TYPE_CHECKING
 
 from griffe.docstrings.dataclasses import (
     DocstringAttribute,
@@ -50,7 +50,18 @@ from griffe.docstrings.dataclasses import (
     DocstringReceive,
     DocstringReturn,
     DocstringSection,
+    DocstringSectionAttributes,
+    DocstringSectionDeprecated,
+    DocstringSectionExamples,
     DocstringSectionKind,
+    DocstringSectionOtherParameters,
+    DocstringSectionParameters,
+    DocstringSectionRaises,
+    DocstringSectionReceives,
+    DocstringSectionReturns,
+    DocstringSectionText,
+    DocstringSectionWarns,
+    DocstringSectionYields,
     DocstringWarn,
     DocstringYield,
 )
@@ -58,6 +69,8 @@ from griffe.docstrings.utils import warning
 from griffe.expressions import Expression, Name
 
 if TYPE_CHECKING:
+    from typing import Any, Literal, Pattern  # type: ignore[attr-defined]
+
     from griffe.dataclasses import Docstring
 
 _warn = warning(__name__)
@@ -190,6 +203,8 @@ _RE_PARAMETER: Pattern = re.compile(
     """,
     re.IGNORECASE | re.VERBOSE,
 )
+_RE_DOCTEST_BLANKLINE: Pattern = re.compile(r"^\s*<BLANKLINE>\s*$")
+_RE_DOCTEST_FLAGS: Pattern = re.compile(r"(\s*#\s*doctest:.+)$")
 
 
 def _read_parameters(docstring: Docstring, offset: int) -> tuple[list[DocstringParameter], int]:  # noqa: WPS231
@@ -239,27 +254,39 @@ def _read_parameters(docstring: Docstring, offset: int) -> tuple[list[DocstringP
     return parameters, index
 
 
-def _read_parameters_section(docstring: Docstring, offset: int) -> tuple[DocstringSection | None, int]:
+def _read_parameters_section(
+    docstring: Docstring,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionParameters | None, int]:
     parameters, index = _read_parameters(docstring, offset)
 
     if parameters:
-        return DocstringSection(DocstringSectionKind.parameters, parameters), index
+        return DocstringSectionParameters(parameters), index
 
     _warn(docstring, index, f"Empty parameters section at line {offset}")
     return None, index
 
 
-def _read_other_parameters_section(docstring: Docstring, offset: int) -> tuple[DocstringSection | None, int]:
+def _read_other_parameters_section(
+    docstring: Docstring,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionOtherParameters | None, int]:
     parameters, index = _read_parameters(docstring, offset)
 
     if parameters:
-        return DocstringSection(DocstringSectionKind.other_parameters, parameters), index
+        return DocstringSectionOtherParameters(parameters), index
 
     _warn(docstring, index, f"Empty other parameters section at line {offset}")
     return None, index
 
 
-def _read_deprecated_section(docstring: Docstring, offset: int) -> tuple[DocstringSection | None, int]:
+def _read_deprecated_section(
+    docstring: Docstring,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionDeprecated | None, int]:
     # deprecated
     # SINCE_VERSION
     #     TEXT?
@@ -275,10 +302,14 @@ def _read_deprecated_section(docstring: Docstring, offset: int) -> tuple[Docstri
     item = items[0]
     version = item[0]
     text = dedent("\n".join(item[1:]))
-    return DocstringSection(DocstringSectionKind.deprecated, (version, text)), index
+    return DocstringSectionDeprecated(version=version, text=text), index
 
 
-def _read_returns_section(docstring: Docstring, offset: int) -> tuple[DocstringSection | None, int]:
+def _read_returns_section(
+    docstring: Docstring,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionReturns | None, int]:
     # returns
     # (NAME : )?TYPE
     #     TEXT?
@@ -298,10 +329,14 @@ def _read_returns_section(docstring: Docstring, offset: int) -> tuple[DocstringS
         name, annotation = match.groups()
         text = dedent("\n".join(item[1:]))
         returns.append(DocstringReturn(name=name or "", annotation=annotation, description=text))
-    return DocstringSection(DocstringSectionKind.returns, returns), index
+    return DocstringSectionReturns(returns), index
 
 
-def _read_yields_section(docstring: Docstring, offset: int) -> tuple[DocstringSection | None, int]:
+def _read_yields_section(
+    docstring: Docstring,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionYields | None, int]:
     # yields
     # (NAME : )?TYPE
     #     TEXT?
@@ -321,10 +356,14 @@ def _read_yields_section(docstring: Docstring, offset: int) -> tuple[DocstringSe
         name, annotation = match.groups()
         text = dedent("\n".join(item[1:]))
         yields.append(DocstringYield(name=name or "", annotation=annotation, description=text))
-    return DocstringSection(DocstringSectionKind.yields, yields), index
+    return DocstringSectionYields(yields), index
 
 
-def _read_receives_section(docstring: Docstring, offset: int) -> tuple[DocstringSection | None, int]:
+def _read_receives_section(
+    docstring: Docstring,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionReceives | None, int]:
     # receives
     # (NAME : )?TYPE
     #     TEXT?
@@ -344,10 +383,14 @@ def _read_receives_section(docstring: Docstring, offset: int) -> tuple[Docstring
         name, annotation = match.groups()
         text = dedent("\n".join(item[1:]))
         receives.append(DocstringReceive(name=name or "", annotation=annotation, description=text))
-    return DocstringSection(DocstringSectionKind.receives, receives), index
+    return DocstringSectionReceives(receives), index
 
 
-def _read_raises_section(docstring: Docstring, offset: int) -> tuple[DocstringSection | None, int]:
+def _read_raises_section(
+    docstring: Docstring,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionRaises | None, int]:
     # raises
     # EXCEPTION
     #     TEXT?
@@ -362,10 +405,14 @@ def _read_raises_section(docstring: Docstring, offset: int) -> tuple[DocstringSe
         annotation = item[0]
         text = dedent("\n".join(item[1:]))
         raises.append(DocstringRaise(annotation=annotation, description=text))
-    return DocstringSection(DocstringSectionKind.raises, raises), index
+    return DocstringSectionRaises(raises), index
 
 
-def _read_warns_section(docstring: Docstring, offset: int) -> tuple[DocstringSection | None, int]:
+def _read_warns_section(
+    docstring: Docstring,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionWarns | None, int]:
     # warns
     # WARNING
     #     TEXT?
@@ -380,10 +427,14 @@ def _read_warns_section(docstring: Docstring, offset: int) -> tuple[DocstringSec
         annotation = item[0]
         text = dedent("\n".join(item[1:]))
         warns.append(DocstringWarn(annotation=annotation, description=text))
-    return DocstringSection(DocstringSectionKind.warns, warns), index
+    return DocstringSectionWarns(warns), index
 
 
-def _read_attributes_section(docstring: Docstring, offset: int) -> tuple[DocstringSection | None, int]:
+def _read_attributes_section(
+    docstring: Docstring,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionAttributes | None, int]:
     # attributes (for classes)
     # NAME( : TYPE)?
     #    TEXT?
@@ -404,13 +455,18 @@ def _read_attributes_section(docstring: Docstring, offset: int) -> tuple[Docstri
             annotation = None
         text = dedent("\n".join(item[1:]))
         attributes.append(DocstringAttribute(name=name, annotation=annotation, description=text))
-    return DocstringSection(DocstringSectionKind.attributes, attributes), index
+    return DocstringSectionAttributes(attributes), index
 
 
-def _read_examples_section(docstring: Docstring, offset: int) -> tuple[DocstringSection | None, int]:  # noqa: WPS231
+def _read_examples_section(  # noqa: WPS231
+    docstring: Docstring,
+    offset: int,
+    trim_doctest_flags: bool = True,
+    **options: Any,
+) -> tuple[DocstringSectionExamples | None, int]:
     text, index = _read_block(docstring, offset)
 
-    sub_sections = []
+    sub_sections: list[tuple[Literal[DocstringSectionKind.text] | Literal[DocstringSectionKind.examples], str]] = []
     in_code_example = False
     in_code_block = False
     current_text: list[str] = []
@@ -427,6 +483,9 @@ def _read_examples_section(docstring: Docstring, offset: int) -> tuple[Docstring
                 current_text.append(line)
 
         elif in_code_example:
+            if trim_doctest_flags:
+                line = _RE_DOCTEST_FLAGS.sub("", line)
+                line = _RE_DOCTEST_BLANKLINE.sub("", line)
             current_example.append(line)
 
         elif line.startswith("```"):
@@ -441,6 +500,9 @@ def _read_examples_section(docstring: Docstring, offset: int) -> tuple[Docstring
                 sub_sections.append((DocstringSectionKind.text, "\n".join(current_text).rstrip("\n")))
                 current_text = []
             in_code_example = True
+
+            if trim_doctest_flags:
+                line = _RE_DOCTEST_FLAGS.sub("", line)
             current_example.append(line)
 
         else:
@@ -452,7 +514,7 @@ def _read_examples_section(docstring: Docstring, offset: int) -> tuple[Docstring
         sub_sections.append((DocstringSectionKind.examples, "\n".join(current_example)))
 
     if sub_sections:
-        return DocstringSection(DocstringSectionKind.examples, sub_sections), index
+        return DocstringSectionExamples(sub_sections), index
 
     _warn(docstring, index, f"Empty examples section at line {offset}")
     return None, index
@@ -474,6 +536,7 @@ _section_reader = {
 
 def parse(  # noqa: WPS231
     docstring: Docstring,
+    trim_doctest_flags: bool = True,
     **options: Any,
 ) -> list[DocstringSection]:
     """Parse a docstring.
@@ -483,16 +546,22 @@ def parse(  # noqa: WPS231
 
     Parameters:
         docstring: The docstring to parse.
+        trim_doctest_flags: Whether to remove doctest flags from Python example blocks.
         **options: Additional parsing options.
 
     Returns:
         A list of docstring sections.
     """
-    sections = []
+    sections: list[DocstringSection] = []
     current_section = []
 
     in_code_block = False
 
+    options = {
+        "trim_doctest_flags": trim_doctest_flags,
+        **options,
+    }
+
     lines = docstring.lines
     index = 0
 
@@ -507,12 +576,10 @@ def parse(  # noqa: WPS231
         elif line_lower in _section_kind and _is_dash_line(lines[index + 1]):
             if current_section:
                 if any(current_section):
-                    sections.append(
-                        DocstringSection(DocstringSectionKind.text, "\n".join(current_section).rstrip("\n"))
-                    )
+                    sections.append(DocstringSectionText("\n".join(current_section).rstrip("\n")))
                 current_section = []
             reader = _section_reader[_section_kind[line_lower]]
-            section, index = reader(docstring, index + 2)
+            section, index = reader(docstring, index + 2, **options)  # type: ignore[operator]
             if section:
                 sections.append(section)
 
@@ -526,6 +593,6 @@ def parse(  # noqa: WPS231
         index += 1
 
     if current_section:
-        sections.append(DocstringSection(DocstringSectionKind.text, "\n".join(current_section).rstrip("\n")))
+        sections.append(DocstringSectionText("\n".join(current_section).rstrip("\n")))
 
     return sections
